--- ========================================================= ---
---  Setup Revision, Version, Date and add to AceLibrary
--- ========================================================= ---
local VERSION = tonumber(("$Revision: 43322 $"):match("%d+"))

local Sphere = Sphere
Sphere_ButtonSkins = Sphere:NewModule("ButtonSkins", "AceEvent-2.0")
local self = Sphere_ButtonSkins
if Sphere.revision < VERSION then
	Sphere.version = "r" .. VERSION
	Sphere.revision = VERSION
	Sphere.date = ("$Date: 2007-07-09 18:20:48 -0400 (Mon, 09 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end
Sphere.desc = "Adds Buttons to the Sphere"

--- ========================================================= ---
---  Setup Locals
--- ========================================================= ---
local L = Sphere:L("Sphere_ButtonSkins")

local skinValidate = {
	metallic = L["Metallic"],
}								

local skinValidateDesc = {}

--- ========================================================= ---
---  On Intitalize / Setup Database
--- ========================================================= ---
function Sphere_ButtonSkins:OnInitialize()
	self.db = Sphere:AcquireDBNamespace("ButtonSkins")
	Sphere:RegisterDefaults("ButtonSkins", "char", {
		settings = {
			skin = "metallic"
		},
	})

end

--- ========================================================= ---
---  Setup Options
--- ========================================================= ---
Sphere_ButtonSkins:RegisterSphereOption({
	name = L["Button Skins"],
	desc = L["Change the Skin the Buttons use."],
	type = 'group',
	args = {
		skin = {
			name = L["Skin"],
			desc = L["Choose Skin."],
			type = 'text',
			validate = skinValidate,
			validateDesc = skinValidateDesc,
			get = function()
				return self.db.char.settings.skin
			end,
			set = "SetSkin",
		},
	}
})

--- ========================================================= ---
---  On Enable
--- ========================================================= ---
function Sphere_ButtonSkins:OnEnable()
	self:ProcessSkins()
end

--- ========================================================= ---
---  On Disable
--- ========================================================= ---
function Sphere_ButtonSkins:OnDisable()
	self:UnregisterAllEvents();
end

--- ========================================================= ---
---  Set Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetSkin(value)
	if value then
		self.db.char.settings.skin = value
	else
		value = self.db.char.settings.skin
	end
	
	Process_ButtonSkins:ProcessSkins()
end

--- ========================================================= ---
---  Apply Skin
--- ========================================================= ---
function Sphere_ButtonSkins:ProcessSkins()

	if Sphere:HasModule('Buttons') then
		for i=1, 10 do
			local btn = "SphereBar"..i.."Button1"
			Sphere_ButtonSkins:SetFrameSkin(btn)
			Sphere_ButtonSkins:SetIconSkin(btn)
			Sphere_ButtonSkins:SetNormalSkin(btn)
			Sphere_ButtonSkins:SetHighlightSkin(btn)
			Sphere_ButtonSkins:SetPushedSkin(btn)
			Sphere_ButtonSkins:SetCheckedSkin(btn)
			Sphere_ButtonSkins:SetOverlaySkin(btn)
			Sphere_ButtonSkins:SetCooldownSkin(btn)
			Sphere_ButtonSkins:SetFlashSkin(btn)
			Sphere_ButtonSkins:SetHotkeySkin(btn)
			Sphere_ButtonSkins:SetCountSkin(btn)
		end
	end
	
	if Sphere:HasModule('SubButtons') then
		for iM = 1, 10 do
			for i = 1, 10 do
				local btn = "SphereSubBar"..iM.."Button"..i
				Sphere_ButtonSkins:SetFrameSkin(btn)
				Sphere_ButtonSkins:SetIconSkin(btn)
				Sphere_ButtonSkins:SetNormalSkin(btn)
				Sphere_ButtonSkins:SetHighlightSkin(btn)
				Sphere_ButtonSkins:SetPushedSkin(btn)
				Sphere_ButtonSkins:SetCheckedSkin(btn)
				Sphere_ButtonSkins:SetOverlaySkin(btn)
				Sphere_ButtonSkins:SetCooldownSkin(btn)
				Sphere_ButtonSkins:SetFlashSkin(btn)
				Sphere_ButtonSkins:SetHotkeySkin(btn)
				Sphere_ButtonSkins:SetCountSkin(btn)
			end
		end
	end

end

--- ========================================================= ---
---  Apply Skin
--- ========================================================= ---
function Sphere_ButtonSkins:ApplySkin(obj, type)

	if not obj then return end
	if not SphereButtonSkins[self.db.char.settings.skin][type] then return end
	
	local texture
	local skin = SphereButtonSkins[self.db.char.settings.skin][type]
	
	if skin.scale then
		obj:SetScale(skin.scale)
	end
	
	if skin.framelevel then
		obj:SetFrameLevel(skin.framelevel)
	end
	
	if skin.framestrata then
		obj:SetFrameStrata(skin.framestrata)
	end
	
	if skin.drawlayer then
		obj:SetDrawLayer(skin.drawlayer)
	end
	
	if skin.height then
		obj:SetHeight(skin.height)
	end
	
	if skin.width then
		obj:SetWidth(skin.width)
	end
	
	if skin.alpha then
		obj:SetAlpha(skin.alpha)
	end	
	
	if skin.point ~= "NONE" then
		obj:ClearAllPoints();
		obj:SetPoint((skin.point or "CENTER"), (skin.x or 0), (skin.y or 0))
	end
	
	if skin.texture then
		texture = skin.texture
	end
	
	if skin.blend then
		obj:SetBlendMode(skin.blend)
	end
	
	return texture

end

--- ========================================================= ---
---  Set Frame Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetFrameSkin(btn)
	local obj = getglobal(btn)
	Sphere_ButtonSkins:ApplySkin(obj, "frame")
end

--- ========================================================= ---
---  Set Icon Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetIconSkin(btn)
	local obj = getglobal(btn.."Icon")
	Sphere_ButtonSkins:ApplySkin(obj, "icon")
end

--- ========================================================= ---
---  Set Normal Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetNormalSkin(btn)
	local obj = getglobal(btn):GetNormalTexture();
	texture = Sphere_ButtonSkins:ApplySkin(obj, "normal")
	getglobal(btn):SetNormalTexture(texture)
end
--- ========================================================= ---
---  Set Highlight Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetHighlightSkin(btn)
	local obj = getglobal(btn):GetHighlightTexture();
	texture = Sphere_ButtonSkins:ApplySkin(obj, "highlight")
	getglobal(btn):SetHighlightTexture(texture)
	
	local r, g, b, a = unpack(Sphere.db.namespaces.Buttons.char.colors.buttonhighlightborder)
	obj:SetVertexColor(r, g, b, a)
end

--- ========================================================= ---
---  Set Pushed Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetPushedSkin(btn)
	local obj = getglobal(btn):GetPushedTexture();
	texture = Sphere_ButtonSkins:ApplySkin(obj, "pushed")
	getglobal(btn):SetPushedTexture(texture)
end

--- ========================================================= ---
---  Set Checked Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetCheckedSkin(btn)
	local obj = getglobal(btn):GetCheckedTexture();
	texture = Sphere_ButtonSkins:ApplySkin(obj, "checked")
	getglobal(btn):SetCheckedTexture(texture)
end

--- ========================================================= ---
---  Set Overlay Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetOverlaySkin(btn)
	getglobal(btn):CreateTexture(btn.."Overlay", "OVERLAY")
	local obj = getglobal(btn.."Overlay")
	texture = Sphere_ButtonSkins:ApplySkin(obj, "overlay")
	getglobal(btn.."Overlay"):SetTexture(texture)
end

--- ========================================================= ---
---  Set Cooldown Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetCooldownSkin(btn)
	local obj = getglobal(btn.."Cooldown")
	Sphere_ButtonSkins:ApplySkin(obj, "cooldown")
end

--- ========================================================= ---
---  Set Flash Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetFlashSkin(btn)
	local obj = getglobal(btn.."Cooldown")
	Sphere_ButtonSkins:ApplySkin(obj, "flash")
end

--- ========================================================= ---
---  Set Hotkey Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetHotkeySkin(btn)
	local obj = getglobal(btn.."HotKey")
	Sphere_ButtonSkins:ApplySkin(obj, "hotkey")
end

--- ========================================================= ---
---  Set Count Skin
--- ========================================================= ---
function Sphere_ButtonSkins:SetCountSkin(btn)
	local obj = getglobal(btn.."Count")
	Sphere_ButtonSkins:ApplySkin(obj, "count")
end