--- ========================================================= ---
---  Setup Revision, Version, Date and add to AceLibrary
--- ========================================================= ---
local VERSION = tonumber(("$Revision: 44107 $"):match("%d+"))

local Sphere = Sphere
Sphere_ClassModule_Druid = Sphere:NewModule("ClassModule_Druid", "AceEvent-2.0")
local self = Sphere_ClassModule_Druid
if Sphere.revision < VERSION then
	Sphere.version = "r" .. VERSION
	Sphere.revision = VERSION
	Sphere.date = ("$Date: 2007-07-18 15:15:25 -0400 (Wed, 18 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end
Sphere.desc = "Druid Class Module"

--- ========================================================= ---
---  Setup Locals
--- ========================================================= ---
local L = Sphere:L("Sphere_ClassModule_Druid")

local data = {
	outerplayerMana = 0,
	innerplayerMana = 0,
	coverplayerMana = 0,
	covertplayerMana = 0,
	outerfiveSec = 5,
	innerfiveSec = 5,
	coverfiveSec = 5,
	covertfiveSec = 5,
}

--- ========================================================= ---
---  On Intitalize / Setup Database
--- ========================================================= ---
function Sphere_ClassModule_Druid:OnInitialize()
	self.db = Sphere:AcquireDBNamespace("ClassModule_Druid")
	Sphere:RegisterDefaults("ClassModule_Druid", "char", {
		settings = {
		},
		colors = {
			fivesec = {1, 1, 1, 1},
		},
	})

	Sphere_ClassModule_Druid:CheckClass()
end

--- ========================================================= ---
---  Setup Options
--- ========================================================= ---
local playerClass, englishClass = UnitClass("player");
if englishClass == "DRUID" then
	Sphere.options.args.appearance.args.colors.args.fivesecColor = {
		name = L["Five Sec Colors"],
		desc = L["Set what color five sec color is."],
		type = 'group',
		pass = true,
		get = function(value)
			return unpack(self.db.char.colors[value])
		end,
		set = "SetDruidColor",
		args = {
			fivesec = {
				name = L["Five Sec"],
				desc = L["Color for Five Sec."],
				type = 'color',
				hasAlpha = false,
			},
		},
	}
end

--- ========================================================= ---
---  On Enable
--- ========================================================= ---
function Sphere_ClassModule_Druid:OnEnable()
	Sphere_ClassModule_Druid:AddToOuterGaugeOptions()
	Sphere_ClassModule_Druid:AddToInnerGaugeOptions()
	Sphere_ClassModule_Druid:AddToCoverGaugeOptions()
	Sphere_ClassModule_Druid:AddToCoverTextOptions()
end

--- ========================================================= ---
---  On Disable
--- ========================================================= ---
function Sphere_ClassModule_Druid:OnDisable()
	Sphere_ClassModule_Druid:RemoveFromOuterGaugeOptions()
	Sphere_ClassModule_Druid:RemoveFromInnerGaugeOptions()
	Sphere_ClassModule_Druid:RemoveFromCoverGaugeOptions()
	Sphere_ClassModule_Druid:RemoveFromCoverTextOptions()
	
	self:UnregisterAllEvents();
end

--- ========================================================= ---
---  Check Class
--- ========================================================= ---
function Sphere_ClassModule_Druid:CheckClass()
	local playerClass, englishClass = UnitClass("player");
	if englishClass ~= "DRUID" then
		Sphere:ToggleModuleActive("ClassModule_Druid", false)
	else
		Sphere:ToggleModuleActive("ClassModule_Druid", true)
	end
end

--- ========================================================= ---
---  Add To Outer Gauge Options
--- ========================================================= ---
function Sphere_ClassModule_Druid:AddToOuterGaugeOptions()
	local func = Sphere_eventTypeValidate
	local key = "Custom_ClassModule_Druid_OuterGaugeFiveSec"
	local value = L["Five Sec"]
	Sphere:AddEventType(func, key, value)
end

--- ========================================================= ---
---  Add To Inner Gauge Options
--- ========================================================= ---
function Sphere_ClassModule_Druid:AddToInnerGaugeOptions()
	local func = Sphere_InnerGauge_eventTypeValidate
	local key = "Custom_ClassModule_Druid_InnerGaugeFiveSec"
	local value = L["Five Sec"]
	Sphere_InnerGauge:AddEventType(func, key, value)
end

--- ========================================================= ---
---  Add To Cover Gauge Options
--- ========================================================= ---
function Sphere_ClassModule_Druid:AddToCoverGaugeOptions()
	local func = Sphere_CoverGauge_eventTypeValidate
	local key = "Custom_ClassModule_Druid_CoverGaugeFiveSec"
	local value = L["Five Sec"]
	Sphere_CoverGauge:AddEventType(func, key, value)
end

--- ========================================================= ---
---  Add To Cover Text Options
--- ========================================================= ---
function Sphere_ClassModule_Druid:AddToCoverTextOptions()
	local func = Sphere_CoverText_eventTypeValidate
	local key = "Custom_ClassModule_Druid_CoverTextFiveSec"
	local value = L["Five Sec"]
	Sphere_CoverText:AddEventType(func, key, value)
end

--- ========================================================= ---
---  Remove From Outer Gauge Options
--- ========================================================= ---
function Sphere_ClassModule_Druid:RemoveFromOuterGaugeOptions()
	local func = Sphere_eventTypeValidate
	local key = "Custom_ClassModule_Druid_OuterGaugeFiveSec"
	Sphere:RemoveEventType(func, key)
end

--- ========================================================= ---
---  Remove From Inner Gauge Options
--- ========================================================= ---
function Sphere_ClassModule_Druid:RemoveFromInnerGaugeOptions()
	local func = Sphere_InnerGauge_eventTypeValidate
	local key = "Custom_ClassModule_Druid_InnerGaugeFiveSec"
	Sphere_InnerGauge:RemoveEventType(func, key)
end

--- ========================================================= ---
---  Remove From Cover Gauge Options
--- ========================================================= ---
function Sphere_ClassModule_Druid:RemoveFromCoverGaugeOptions()
	local func = Sphere_CoverGauge_eventTypeValidate
	local key = "Custom_ClassModule_Druid_CoverGaugeFiveSec"
	Sphere_CoverGauge:RemoveEventType(func, key)
end

--- ========================================================= ---
---  Remove From Cover Text Options
--- ========================================================= ---
function Sphere_ClassModule_Druid:RemoveFromCoverTextOptions()
	local func = Sphere_CoverText_eventTypeValidate
	local key = "Custom_ClassModule_Druid_CoverTextFiveSec"
	Sphere_CoverText:RemoveEventType(func, key)
end

--- ========================================================= ---
---  Set Five Sec Color
--- ========================================================= ---
function Sphere:SetDruidColor(given_kind, r, g, b, a)
	local kind = given_kind
	local colors = Sphere.db.namespaces.ClassModule_Druid.char.colors[kind]
	
	if r then
		colors[1] = r
		colors[2] = g
		colors[3] = b
		colors[4] = a
	else
		r, g, b, a = unpack(colors)
	end
end

--- ========================================================= ---
---  Outer Five Sec
--- ========================================================= ---
function Sphere:Custom_ClassModule_Druid_OuterGaugeFiveSec()
	local checkMana = UnitMana("player")
	local sPercent, r, g, b, a
	
	if (checkMana < data.outerplayerMana) then
		data.outerfiveSec = 0;
	else
		if (data.outerfiveSec < 5) then
			data.outerfiveSec = (data.outerfiveSec + 0.05)
		else
			data.outerfiveSec = 5
		end
	end
	data.outerplayerMana = checkMana
	sPercent = data.outerfiveSec * 20
	r, g, b, a = unpack(Sphere.db.namespaces.ClassModule_Druid.char.colors.fivesec)
	
	return sPercent, r, g, b, a
end

--- ========================================================= ---
---  Inner Five Sec
--- ========================================================= ---
function Sphere:Custom_ClassModule_Druid_InnerGaugeFiveSec()
	local checkMana = UnitMana("player")
	local sPercent, r, g, b, a
	
	if (checkMana < data.innerplayerMana) then
		data.innerfiveSec = 0;
	else
		if (data.innerfiveSec < 5) then
			data.innerfiveSec = (data.innerfiveSec + 0.05)
		else
			data.innerfiveSec = 5
		end
	end
	data.innerplayerMana = checkMana
	sPercent = data.innerfiveSec * 20
	r, g, b, a = unpack(Sphere.db.namespaces.ClassModule_Druid.char.colors.fivesec)
	
	return sPercent, r, g, b, a
end

--- ========================================================= ---
---  Cover Five Sec
--- ========================================================= ---
function Sphere:Custom_ClassModule_Druid_CoverGaugeFiveSec()
	local checkMana = UnitMana("player")
	local sPercent, r, g, b, a
	
	if (checkMana < data.coverplayerMana) then
		data.coverfiveSec = 0;
	else
		if (data.coverfiveSec < 5) then
			data.coverfiveSec = (data.coverfiveSec + 0.05)
		else
			data.coverfiveSec = 5
		end
	end
	data.coverplayerMana = checkMana
	sPercent = data.coverfiveSec * 20 / 100
	r, g, b, a = unpack(Sphere.db.namespaces.ClassModule_Druid.char.colors.fivesec)
	
	return sPercent, r, g, b, a
end

--- ========================================================= ---
---  Cover Text Five Sec
--- ========================================================= ---
function Sphere:Custom_ClassModule_Druid_CoverTextFiveSec()
	local checkMana = UnitMana("player")
	
	if (checkMana < data.covertplayerMana) then
		data.covertfiveSec = 0;
	else
		if (data.covertfiveSec < 5) then
			data.covertfiveSec = (data.covertfiveSec + 0.05)
		else
			data.covertfiveSec = 5
		end
	end
	data.covertplayerMana = checkMana
	sText = math.floor(data.covertfiveSec)
	
	if (sText >= 5) then
		sText = ""
	end
	
	return sText
end