--- ========================================================= ---
---  Setup Revision, Version, Date and add to AceLibrary
--- ========================================================= ---
local VERSION = tonumber(("$Revision: 44247 $"):match("%d+"))

local Sphere = Sphere
Sphere_CoverText = Sphere:NewModule("CoverText", "AceEvent-2.0")
local self = Sphere_CoverText
if Sphere.revision < VERSION then
	Sphere.version = "r" .. VERSION
	Sphere.revision = VERSION
	Sphere.date = ("$Date: 2007-07-19 15:21:49 -0400 (Thu, 19 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end
Sphere.desc = "Adds Cover Text to the Sphere"


--- ========================================================= ---
---  Setup Locals
--- ========================================================= ---
local DogTag = AceLibrary("DogTag-1.0")

local L = Sphere:L("Sphere_CoverText")

local eventType = {
	health = "[PercentHP:Percent]",
	power = "[PercentMP:Percent]",
	threat = "[PercentThreat:Percent]",
	experience = "[PercentXP:Percent]",
	reputation = "[PercentRep:Percent]",
	none = "",
	custom = "",
}

--- ========================================================= ---
---  On Intitalize / Setup Database
--- ========================================================= ---
function Sphere_CoverText:OnInitialize()
	self.db = Sphere:AcquireDBNamespace("CoverText")
	Sphere:RegisterDefaults("CoverText", "char", {
		colors = {
			text = {1, 1, 1, 1},
			background = {0, 0, 0, 0.75},
		},
		gaugeUnit = "player",
		gaugeType = "experience",
		gaugeCustom = "[PercentXP:Percent]",
		background = true,
		useCustom = false,
	})

	self:CreateFrames()
end

--- ========================================================= ---
---  Setup Validates for Options
--- ========================================================= ---
Sphere_CoverText_eventTypeValidate = {
	health = L["Health"],
	power = L["Power"],
	threat = L["Threat"],
	experience = L["Experience"],
	reputation = L["Reputation"],
	custom = L["Custom"],
	none = L["None"],
}

local eventTypeValidateDesc = {}

local eventUnitValidate = {
	player = L["Player"],
	target = L["Target"],
	focus = L["Focus"],
	pet = L["Pet"],
}

local eventUnitValidateDesc = {}

--- ========================================================= ---
---  Setup Options
--- ========================================================= ---
Sphere_CoverText:RegisterSphereOption({
	name = L["Cover Text"],
	desc = L["Change the Cover Text options."],
	type = 'group',
	args = {
		colors = {
			name = L["Colors"],
			desc = L["Change the Colors that the Covet Text uses."],
			type = 'group',
			pass = true,
			get = function(value)
				return unpack(self.db.char.colors[value])
			end,
			set = "SetColor",
			args = {
				text = {
					name = L["Text"],
					desc = L["Color for your Text."],
					type = 'color',
					hasAlpha = true,
				},
				background = {
					name = L["Background"],
					desc = L["Color for your Background."],
					type = 'color',
					hasAlpha = true,
				},
			},
		},
		event = {
			name = L["Event Type"],
			desc = L["Choose which Event Type the Gauge monitors and shows."],
			type = 'text',
			validate = Sphere_CoverText_eventTypeValidate,
			validateDesc = eventTypeValidateDesc,
			get = function()
				return self.db.char.gaugeType
			end,
			set = "SetGaugeType",
		},
		unit = {
			name = L["Event Unit"],
			desc = L["Choose which Unit the Event is monitoring and showing."],
			type = 'text',
			validate = eventUnitValidate,
			validateDesc = eventUnitValidateDesc,
			get = function()
				return self.db.char.gaugeUnit
			end,
			set = "SetGaugeUnit",
		},
		custom = {
			name = L["Custom Event"],
			desc = L["Create a Custom Event for the Gauge to monitor and show."],
			type = "text",
			get = function()
				return self.db.char.gaugeCustom
			end,
			set = "SetCustomGauge",
			usage = L["DogTag-1.0 tags. See http://www.wowace.com/wiki/DogTag-1.0"],
		},
		background = {
			name = L["Show Background"],
			desc = L["Show a Background so the Text can show up better."],
			type = 'toggle',
			get = function()
				return self.db.char.background
			end,
			set = function() 
				self.db.char.background = not(self.db.char.background);
			end,
		},

	}

})

--- ========================================================= ---
---  On Enable
--- ========================================================= ---
function Sphere_CoverText:OnEnable()
	self:ScheduleRepeatingEvent("UpdateCoverText", self.UpdateText, 0.05, self)
	coverTextBG:Show();
	coverText:Show();
end

--- ========================================================= ---
---  On Disable
--- ========================================================= ---
function Sphere_CoverText:OnDisable()
	self:UnregisterAllEvents();
	coverTextBG:Hide();
	coverText:Hide();
end

--- ========================================================= ---
---  Add Event Type
--- ========================================================= ---
function Sphere_CoverText:AddEventType(func, key, value)
	func[key] = value
end

--- ========================================================= ---
---  Remove Event Type
--- ========================================================= ---
function Sphere_CoverText:RemoveEventType(func, key)
	func[key] = nil
end

--- ========================================================= ---
---  Set Color
--- ========================================================= ---
function Sphere_CoverText:SetColor(given_kind, r, g, b, a)
	local kind = given_kind
	local colors = self.db.char.colors[kind]
	
	if r then
		colors[1] = r
		colors[2] = g
		colors[3] = b
		colors[4] = a
	else
		r, g, b, a = unpack(colors)
	end
end

--- ========================================================= ---
--- Create Sphere Frames
--- ========================================================= ---
function Sphere_CoverText:CreateFrames()
	Sphere:CreateFrame("Frame", "SphereCoverText", SphereMainFrame, 10, "Interface\\Addons\\Sphere\\art\\spherecover")

	coverText = SphereCoverText:CreateFontString(nil, "OVERLAY")
	coverText:SetFont(STANDARD_TEXT_FONT, 8)
	coverText:SetPoint("Center");
	coverText:SetText("");
		
	coverTextBG = SphereCoverText:CreateTexture(nil, "ART")
	coverTextBG:SetPoint("Center");
	coverTextBG:SetHeight(9);

end

--- ========================================================= ---
---  Set Gauge Type
--- ========================================================= ---
function Sphere_CoverText:SetGaugeType(value)
	if value then
		self.db.char.gaugeType = value
		self.db.char.gaugeCustom = eventType[value]
	else
		value = self.db.char.gaugeType
	end
	
	if value == "health" or value == "power" or value == "threat" or value == "experience" or value == "reputation" or value == "custom" or value == "none" then
		 self.db.char.useCustom = false
	else
		self.db.char.useCustom = true
	end
end

--- ========================================================= ---
---  Set Gauge Unit
--- ========================================================= ---
function Sphere_CoverText:SetGaugeUnit(value)
	if value then
		self.db.char.gaugeUnit = value
	else
		value = self.db.char.gaugeUnit
	end
end

--- ========================================================= ---
---  Set Custom Gauge
--- ========================================================= ---
function Sphere_CoverText:SetCustomGauge(value)
	if value then
		if self.db.char.gaugeType == "custom" then
			self.db.char.gaugeCustom = value
		else
			self.db.char.gaugeCustom = eventType[self.db.char.gaugeType]
		end
	else
		value = self.db.char.gaugeCustom
	end
end

--- ========================================================= ---
--- Update Gauge
--- ========================================================= ---
function Sphere_CoverText:UpdateText()
	if Sphere:HasModule('InnerGauge') then
		if Sphere:IsModuleActive('InnerGauge') then
			coverText:SetWidth(31);
			coverTextBG:SetWidth(31);
		else
			coverText:SetWidth(45);
			coverTextBG:SetWidth(45);
		end
	else 
		coverText:SetWidth(45);
		coverTextBG:SetWidth(45);
	end
	
	if self.db.char.background then
		local r, g, b, a = unpack(self.db.char.colors.background)
		coverTextBG:SetTexture(r, g, b, a)
		coverTextBG:Show()
	else
		coverTextBG:Hide()
	end

	local r, g, b, a = unpack(self.db.char.colors.text)
	coverText:SetTextColor(r, g, b, a)
	
	if self.db.char.useCustom then
		local sText  = Sphere[self.db.char.gaugeType](Sphere)
		coverText:SetText(sText)
	else
		coverText:SetText(DogTag:Evaluate(self.db.char.gaugeUnit, self.db.char.gaugeCustom))
	end
end