--- ========================================================= ---
---  Setup Revision, Version, Date and add to AceLibrary
--- ========================================================= ---
local VERSION = tonumber(("$Revision: 44107 $"):match("%d+"))

local Sphere = Sphere
Sphere_Module_Combat = Sphere:NewModule("Module_Combat", "AceEvent-2.0")
local self = Sphere_Module_Combat
if Sphere.revision < VERSION then
	Sphere.version = "r" .. VERSION
	Sphere.revision = VERSION
	Sphere.date = ("$Date: 2007-07-18 15:15:25 -0400 (Wed, 18 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end
Sphere.desc = "Combat Module"

--- ========================================================= ---
---  Setup Locals
--- ========================================================= ---
local L = Sphere:L("Sphere_Module_Combat")

local data = {
}

--- ========================================================= ---
---  On Intitalize / Setup Database
--- ========================================================= ---
function Sphere_Module_Combat:OnInitialize()
	self.db = Sphere:AcquireDBNamespace("Module_Combat")
	Sphere:RegisterDefaults("Module_Combat", "char", {
		settings = {
		},
		colors = {
			combat = {1, 0, 0, 1},
		},
	})
end

--- ========================================================= ---
---  Setup Options
--- ========================================================= ---
Sphere.options.args.appearance.args.colors.args.combatColor = {
	name = L["Combat Colors"],
	desc = L["Set what color combat is."],
	type = 'group',
	pass = true,
	get = function(value)
		return unpack(self.db.char.colors[value])
	end,
	set = "SetCombatColor",
	args = {
		combat = {
			name = L["Combat"],
			desc = L["Color for Combat."],
			type = 'color',
			hasAlpha = false,
		},
	},
}

--- ========================================================= ---
---  On Enable
--- ========================================================= ---
function Sphere_Module_Combat:OnEnable()
	Sphere_Module_Combat:AddToOuterGaugeOptions()
	Sphere_Module_Combat:AddToInnerGaugeOptions()
	Sphere_Module_Combat:AddToCoverGaugeOptions()
	Sphere_Module_Combat:AddToCoverTextOptions()
end

--- ========================================================= ---
---  On Disable
--- ========================================================= ---
function Sphere_Module_Combat:OnDisable()
	Sphere_Module_Combat:RemoveFromOuterGaugeOptions()
	Sphere_Module_Combat:RemoveFromInnerGaugeOptions()
	Sphere_Module_Combat:RemoveFromCoverGaugeOptions()
	Sphere_Module_Combat:RemoveFromCoverTextOptions()

	self:UnregisterAllEvents();
end

--- ========================================================= ---
---  Add To Outer Gauge Options
--- ========================================================= ---
function Sphere_Module_Combat:AddToOuterGaugeOptions()
	local func = Sphere_eventTypeValidate
	local key = "Custom_Module_CombatGauge"
	local value = L["Combat"]
	Sphere:AddEventType(func, key, value)
end

--- ========================================================= ---
---  Add To Inner Gauge Options
--- ========================================================= ---
function Sphere_Module_Combat:AddToInnerGaugeOptions()
	local func = Sphere_InnerGauge_eventTypeValidate
	local key = "Custom_Module_CombatGauge"
	local value = L["Combat"]
	Sphere_InnerGauge:AddEventType(func, key, value)
end

--- ========================================================= ---
---  Add To Cover Gauge Options
--- ========================================================= ---
function Sphere_Module_Combat:AddToCoverGaugeOptions()
	local func = Sphere_CoverGauge_eventTypeValidate
	local key = "Custom_Module_CombatGauge"
	local value = L["Combat"]
	Sphere_CoverGauge:AddEventType(func, key, value)
end

--- ========================================================= ---
---  Add To Cover Text Options
--- ========================================================= ---
function Sphere_Module_Combat:AddToCoverTextOptions()
	local func = Sphere_CoverText_eventTypeValidate
	local key = "Custom_Module_CombatText"
	local value = L["Combat"]
	Sphere_CoverText:AddEventType(func, key, value)
end

--- ========================================================= ---
---  Remove From Outer Gauge Options
--- ========================================================= ---
function Sphere_Module_Combat:RemoveFromOuterGaugeOptions()
	local func = Sphere_eventTypeValidate
	local key = "Custom_Module_CombatGauge"
	Sphere:RemoveEventType(func, key)
end

--- ========================================================= ---
---  Remove From Inner Gauge Options
--- ========================================================= ---
function Sphere_Module_Combat:RemoveFromInnerGaugeOptions()
	local func = Sphere_InnerGauge_eventTypeValidate
	local key = "Custom_Module_CombatGauge"
	Sphere_InnerGauge:RemoveEventType(func, key)
end

--- ========================================================= ---
---  Remove From Cover Gauge Options
--- ========================================================= ---
function Sphere_Module_Combat:RemoveFromCoverGaugeOptions()
	local func = Sphere_CoverGauge_eventTypeValidate
	local key = "Custom_Module_CombatGauge"
	Sphere_CoverGauge:RemoveEventType(func, key)
end

--- ========================================================= ---
---  Remove From Cover Text Options
--- ========================================================= ---
function Sphere_Module_Combat:RemoveFromCoverTextOptions()
	local func = Sphere_CoverText_eventTypeValidate
	local key = "Custom_Module_CombatText"
	Sphere_CoverText:RemoveEventType(func, key)
end

--- ========================================================= ---
---  Set Combat Color
--- ========================================================= ---
function Sphere:SetCombatColor(given_kind, r, g, b, a)
	local kind = given_kind
	local colors = Sphere.db.namespaces.Module_Combat.char.colors[kind]
	
	if r then
		colors[1] = r
		colors[2] = g
		colors[3] = b
		colors[4] = a
	else
		r, g, b, a = unpack(colors)
	end
end

--- ========================================================= ---
---  Combat Gauge
--- ========================================================= ---
function Sphere:Custom_Module_CombatGauge()
	local sPercent = 0
	
	if InCombatLockdown() then
		sPercent = 100
	end
	r, g, b, a = unpack(Sphere.db.namespaces.Module_Combat.char.colors.combat)
	
	return sPercent, r, g, b, a
end

--- ========================================================= ---
---  Combat Gauge
--- ========================================================= ---
function Sphere:Custom_Module_CombatText()
	local sText = ""
	
	if InCombatLockdown() then
		sText = "Combat"
	end
	
	return sText
end