--- ========================================================= ---
---  Setup Revision, Version, Date and add to AceLibrary
--- ========================================================= ---
local VERSION = tonumber(("$Revision: 44391 $"):match("%d+"))

local Sphere = Sphere
Sphere_Tooltip = Sphere:NewModule("Tooltip", "AceEvent-2.0")
local self = Sphere_Tooltip
if Sphere.revision < VERSION then
	Sphere.version = "r" .. VERSION
	Sphere.revision = VERSION
	Sphere.date = ("$Date: 2007-07-20 21:22:39 -0400 (Fri, 20 Jul 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end
Sphere.desc = "Adds Buttons to the Sphere"

--- ========================================================= ---
---  Setup Locals
--- ========================================================= ---
local G = AceLibrary('Gratuity-2.0')

local L = Sphere:L("Sphere_Tooltip")

local anchorValidate = {
	anchor = L["Anchor"],
}								

local anchorValidateDesc = {}

local typeValidate = {
	none = L["None"],
	full = L["Full Tooltip"],
	name = L["Name Only"],
	power = L["Power Only"],
	namepower = L["Name & Power Only"],
}								

local typeValidateDesc = {}

--- ========================================================= ---
---  On Intitalize / Setup Database
--- ========================================================= ---
function Sphere_Tooltip:OnInitialize()
	self.db = Sphere:AcquireDBNamespace("Tooltip")
	Sphere:RegisterDefaults("Tooltip", "char", {
		settings = {
			anchor = "cursor",
			type = "full",
		},
	})

end

--- ========================================================= ---
---  Setup Options
--- ========================================================= ---
Sphere_Tooltip:RegisterSphereOption({
	name = L["Tooltip"],
	desc = L["Change the Tooltip options."],
	type = 'group',
	args = {
		settings = {
			name = L["Settings"],
			desc = L["Change the Tooltip Settings in general."],
			type = 'group',
			args = {
				anchor = {
					name = L["Anchor"],
					desc = L["Change where the Tooltip Anchors."],
					type = 'text',
					validate = anchorValidate,
					validateDesc = anchorValidateDesc,
					get = function()
						return self.db.char.settings.anchor
					end,
					set = "SetAnchor",
				},
				anchor = {
					name = L["Type"],
					desc = L["Change what info the Tooltip shows."],
					type = 'text',
					validate = typeValidate,
					validateDesc = typeValidateDesc,
					get = function()
						return self.db.char.settings.type
					end,
					set = "SetType",
				},
			},
		},
	}

})

--- ========================================================= ---
---  On Enable
--- ========================================================= ---
function Sphere_Tooltip:OnEnable()

end

--- ========================================================= ---
---  On Disable
--- ========================================================= ---
function Sphere_Tooltip:OnDisable()
	self:UnregisterAllEvents();
end

--- ========================================================= ---
---  Set Anchor
--- ========================================================= ---
function Sphere_Tooltip:SetAnchor(value)
	if value then
		self.db.char.settings.anchor = value
	else
		value = self.db.char.settings.anchor
	end
end

--- ========================================================= ---
---  Set Type
--- ========================================================= ---
function Sphere_Tooltip:SetType(value)
	if value then
		self.db.char.settings.type = value
	else
		value = self.db.char.settings.type
	end
end

--- ========================================================= ---
--- Create Spell Info for the Tooltip
--- ========================================================= ---

function Sphere_Tooltip:GetSpellTooltipInfo(name)

	local type, amount
	
	local spellid = Sphere_Buttons:GetSpellInfo(name)

	G:SetSpell(spellid, "spell")
	if (G:Find('(%d+)%s'..MANA, 2, 2, false, true)) then
		local mana = tonumber(select(3, G:Find('(%d+)%s'..MANA, 2, 2, false, true))) or 0
				
		type = "Mana"
		amount = mana
		
	elseif (G:Find('(%d+)%s'..ENERGY, 2, 2, false, true)) then
		local energy = tonumber(select(3, G:Find('(%d+)%s'..ENERGY, 2, 2, false, true))) or 0
				
		type = "Energy"
		amount = energy
		
	elseif (G:Find('(%d+)%s'..RAGE, 2, 2, false, true)) then
		local rage = tonumber(select(3, G:Find('(%d+)%s'..RAGE, 2, 2, false, true))) or 0
				
		type = "Rage"
		amount = rage
	end
	
	return type, amount

end

--- ========================================================= ---
--- Create Tooltip
--- ========================================================= ---

function Sphere_Tooltip:SetTooltip(this)
	
	if not this.type then return end
	local type = this.type
	
	if not this.action then return end
	
	GameTooltip:ClearLines();
	
	if (self.db.char.settings.anchor == "cursor") then
		GameTooltip:SetOwner(this, "ANCHOR_CURSOR");
	end
	
	if (self.db.char.settings.type == "full") then
		if (type == "spell") then
			local spellname = string.gsub(this.action, "(%w+[%s()%w]*)%(%)", "%1")
			local spellid = Sphere_Buttons:GetSpellInfo(spellname)
			GameTooltip:SetSpell(spellid, "spell")
		elseif (type == "item") then
			GameTooltip:SetHyperlink(select(2, GetItemInfo(this.action)))
		elseif (type == "macro") then
			local macroName, texture, macrobody, localVar = GetMacroInfo(this.action);
			GameTooltip:SetText(macroName, 1.00, 1.00, 0.00, 1)
			GameTooltip:AddLine(macrobody, 1.00, 1.00, 1.00, 1)
		end
	else
		if (type == "spell") then
			if (self.db.char.settings.type == "name") then
				local spellname = string.gsub(this.action, "(%w+[%s()%w]*)%(%)", "%1")
				GameTooltip:AddLine(spellname, 1.00, 1.00, 0.00, 1)
			elseif (self.db.char.settings.type == "power") then
				local spellname = string.gsub(this.action, "(%w+[%s()%w]*)%(%)", "%1")
				local type, amount = Sphere_Tooltip:GetSpellTooltipInfo(spellname)
				if ((type) and (amount)) then
					GameTooltip:AddLine(amount.." "..type, 1.00, 1.00, 0.00, 1)
				end
			elseif (self.db.char.settings.type == "namepower") then
				local spellname = string.gsub(this.action, "(%w+[%s()%w]*)%(%)", "%1")
				local type, amount = Sphere_Tooltip:GetSpellTooltipInfo(spellname)
				if ((type) and (amount)) then
					GameTooltip:AddLine(spellname, 1.00, 1.00, 0.00, 1)
					GameTooltip:AddLine(amount.." "..type, 1.00, 1.00, 1.00, 1)
				else
					GameTooltip:AddLine(spellname, 1.00, 1.00, 0.00, 1)
				end
			end
		elseif (type == "item") then
			if ((self.db.char.settings.type == "name") or (self.db.char.settings.type == "namepower")) then
				GameTooltip:AddLine(this.action, 1.00, 1.00, 0.00, 1)	
			end
		elseif (type == "macro") then
			if ((self.db.char.settings.type == "name") or (self.db.char.settings.type == "namepower")) then
				local macroName, texture, macrobody, localVar = GetMacroInfo(this.macro);
				GameTooltip:AddLine(macroName, 1.00, 1.00, 0.00, 1)
			end
		end
	end	
	GameTooltip:Show();
end